/* AbiSource Program Utilities
 *
 * Copyright (C) 2005 Daniel d'Andrada T. de Carvalho
 * <daniel.carvalho@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 */

//
// This file is saved with UTF-8 (without signature) encoding;
// please be careful when editing it.
//

#ifndef _ODI_LISTLEVELSTYLEFORMATS_H_
#define _ODI_LISTLEVELSTYLEFORMATS_H_

#define ODI_LISTLEVELSTYLE_ARABIC "أ, ب, ت, ..."

#endif //_ODI_LISTLEVELSTYLEFORMATS_H_
