/* AbiCollab- Code to enable the modification of remote documents.
 * Copyright (C) 2006,2007 Marc Maurer <uwog@uwog.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 */

#ifndef ABI_COLLAB_PLUGIN_H
#define ABI_COLLAB_PLUGIN_H

// Our protocol version. Increase this number whenever you make changes to any
// part of the communication protocols used
#define ABICOLLAB_PROTOCOL_VERSION 	(UT_sint32(11))

#endif /* ABI_COLLAB_PLUGIN_H */
